==> activity-custom-center-api-1.0.19-20240912.062925-5-sources.jar: cn/com/duiba/activity/custom/center/api/dto/wandav1/distribution/WandaDisOrderDto.java <==
package cn.com.duiba.activity.custom.center.api.dto.wandav1.distribution;

import java.time.LocalDateTime;

/**
 * @program: activity-custom-center
 * @description: 万达分销订单dto
 * @author: guo-coffee
 * @create: 2024-09-11
 */
public class WandaDisOrderDto {

    /** 创建时间 */
    private LocalDateTime gmtCreate;

    /** 修改时间 */
    private LocalDateTime gmtModified;

    /** 奖励发放时间 */
    private LocalDateTime rewardTime;

    /** 商品id */
    private String itemId;

    /** 兑吧订单id */
    private String orderId;

    /** 兑吧子订单id */
    private String subOrderId;

    /** 订单信息 */
    private String orderInfo;

    /** 数量 */
    private Integer quantity;

    /** 状态 1: 待审核, 2: 待发货, 3: 已取消, 4: 待完成, 5: 已发放, 6: 已退款 */
    private Integer status;

    /** 奖励积分值 */
    private Long rewards;

    /** 分销员id */
    private String disNo;

    /** 兑吧用户id */
    private String disUserId;

    /** 分销酒店名称 */
    private String disGroggery;

    /** 酒店分销金额（单位：分） */
    private Long disGroggeryReward;

    /** 金额 */
    private Long amount;

    public LocalDateTime getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(LocalDateTime gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public LocalDateTime getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(LocalDateTime gmtModified) {
        this.gmtModified = gmtModified;
    }

    public LocalDateTime getRewardTime() {
        return rewardTime;
    }

    public void setRewardTime(LocalDateTime rewardTime) {
        this.rewardTime = rewardTime;
    }

    public String getItemId() {
        return itemId;
    }

    public void setItemId(String itemId) {
        this.itemId = itemId;
    }

    public String getOrderId() {
        return orderId;
    }

    public void setOrderId(String orderId) {
        this.orderId = orderId;
    }

    public String getSubOrderId() {
        return subOrderId;
    }

    public void setSubOrderId(String subOrderId) {
        this.subOrderId = subOrderId;
    }

    public String getOrderInfo() {
        return orderInfo;
    }

    public void setOrderInfo(String orderInfo) {
        this.orderInfo = orderInfo;
    }

    public Integer getQuantity() {
        return quantity;
    }

    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }

    public String getDisNo() {
        return disNo;
    }

    public void setDisNo(String disNo) {
        this.disNo = disNo;
    }

    public String getDisUserId() {
        return disUserId;
    }

    public void setDisUserId(String disUserId) {
        this.disUserId = disUserId;
    }

    public String getDisGroggery() {
        return disGroggery;
    }

    public void setDisGroggery(String disGroggery) {
        this.disGroggery = disGroggery;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public void setRewards(Long rewards) {
        this.rewards = rewards;
    }

    public void setDisGroggeryReward(Long disGroggeryReward) {
        this.disGroggeryReward = disGroggeryReward;
    }

    public Long getAmount() {
        return amount;
    }

    public void setAmount(Long amount) {
        this.amount = amount;
    }

    public Long getDisGroggeryReward() {
        return disGroggeryReward;
    }

    public Integer getStatus() {
        return status;
    }

    public Long getRewards() {
        return rewards;
    }
}

==> activity-custom-center-api-1.0.19-20240920.081416-27-sources.jar: cn/com/duiba/activity/custom/center/api/dto/wandav1/distribution/WandaDisOrderDto.java <==
package cn.com.duiba.activity.custom.center.api.dto.wandav1.distribution;

import java.io.Serializable;
import java.util.Date;

/**
 * @program: activity-custom-center
 * @description: 万达分销订单dto
 * @author: guo-coffee
 * @create: 2024-09-11
 */
public class WandaDisOrderDto implements Serializable {

    /** 创建时间 */
    private Date gmtCreate;

    /** 修改时间 */
    private Date gmtModified;

    /** 奖励发放时间 */
    private Date rewardTime;

    /** 商品id */
    private Long itemId;

    /** 兑吧订单id */
    private Long orderId;

    /** 兑吧子订单id */
    private Long subOrderId;

    /** 订单信息 */
    private String orderInfo;

    /** 数量 */
    private Integer quantity;

    /** 状态 1: 待审核, 2: 待发货, 3: 已取消, 4: 待完成, 5: 已发放, 6: 已退款 */
    private Integer status;

    /** 奖励积分值 */
    private Long rewards;

    /** 分销员id */
    private String disNo;

    /** 兑吧用户id */
    private Long disUserId;

    /** 分销酒店名称 */
    private String disGroggery;

    /** 分销酒店code **/
    private String disGroggeryCode;


    /** 酒店分销金额（单位：分） */
    private Long disGroggeryReward;

    /** 金额 */
    private Long amount;

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public Long getOrderId() {
        return orderId;
    }

    public void setOrderId(Long orderId) {
        this.orderId = orderId;
    }

    public Long getSubOrderId() {
        return subOrderId;
    }

    public void setSubOrderId(Long subOrderId) {
        this.subOrderId = subOrderId;
    }

    public String getOrderInfo() {
        return orderInfo;
    }

    public void setOrderInfo(String orderInfo) {
        this.orderInfo = orderInfo;
    }

    public Integer getQuantity() {
        return quantity;
    }

    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Long getRewards() {
        return rewards;
    }

    public void setRewards(Long rewards) {
        this.rewards = rewards;
    }

    public String getDisNo() {
        return disNo;
    }

    public void setDisNo(String disNo) {
        this.disNo = disNo;
    }

    public Long getDisUserId() {
        return disUserId;
    }

    public void setDisUserId(Long disUserId) {
        this.disUserId = disUserId;
    }

    public String getDisGroggery() {
        return disGroggery;
    }

    public void setDisGroggery(String disGroggery) {
        this.disGroggery = disGroggery;
    }

    public Long getDisGroggeryReward() {
        return disGroggeryReward;
    }

    public void setDisGroggeryReward(Long disGroggeryReward) {
        this.disGroggeryReward = disGroggeryReward;
    }

    public Long getAmount() {
        return amount;
    }

    public void setAmount(Long amount) {
        this.amount = amount;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getRewardTime() {
        return rewardTime;
    }

    public void setRewardTime(Date rewardTime) {
        this.rewardTime = rewardTime;
    }

    public String getDisGroggeryCode() {
        return disGroggeryCode;
    }

    public void setDisGroggeryCode(String disGroggeryCode) {
        this.disGroggeryCode = disGroggeryCode;
    }
}
